//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[ChitoiHoraHandPattern](index.md)/[roundWind](round-wind.md)

# roundWind

[common]\

@EncodeDefault

open override val [roundWind](round-wind.md): [Wind](../../mahjongutils.models/-wind/index.md)? = null

场风
